@@ -21,9 +21,8 @@
 Command line inputs
 """
 
-from argparse import ArgumentParser, RawDescriptionHelpFormatter
+from argparse import ArgumentParser, Namespace, RawDescriptionHelpFormatter
 from pathlib import Path
-from typing import Dict
 
 from argcomplete import autocomplete
 
@@ -88,7 +87,7 @@ def _cli() -> ArgumentParser:
                         type=str,
                         help='License name or "custom" [default: LGPLv3]')
     parser.add_argument('-y',
-                        '--year',
+                        '--years',
                         default=None,
                         type=str,
                         help='copyright period e.g. 2020-2021')
@@ -110,12 +109,12 @@ def _cli() -> ArgumentParser:
     return parser
 
 
-def cli() -> Dict[str, str]:
+def cli() -> Namespace:
     """
     Command line arguments
     """
     parser = _cli()
-    return vars(parser.parse_args())
+    return parser.parse_args()
 
 
 def configure() -> PyConfig:
@@ -129,11 +128,13 @@ def configure() -> PyConfig:
         NoProjectNameError: project name missing
     """
     cli_inputs = cli()
-    config = read_config(cli_inputs.get('config'))
-    config.update(**cli_inputs)
-    config.license, config.license_header = get_license(cli_inputs['license'])
+    cli_inputs.license, cli_inputs.license_header = get_license(
+        cli_inputs.license)
+    project = cli_inputs.project
+    if project is None:
+        raise NoProjectNameError
+    delattr(cli_inputs, 'project')
+    config = read_config(project=project, **vars(cli_inputs))
     if config.author is None:
         raise NoProjectNameError
-    if config.project is None:
-        raise NoProjectNameError
     return config
