@@ -37,12 +37,10 @@ def edit_modify(text: str, config: PyConfig) -> str:
     Returns:
         modified text
     """
-    for key in config.keys:  # CANT: use __dict__ because uname is a @property
-        value = getattr(config, key)
-        if value is None:
-            continue
-        if isinstance(value, Path):
-            text = text.replace(f'<{key.upper()}>', value.name)
-        else:
-            text = text.replace(f'<{key.upper()}>', value)
+    for key, value in config.__dict__.items():
+        if value is not None:
+            if isinstance(value, Path):
+                text = text.replace(f'<{key.upper()}>', value.name)
+            else:
+                text = text.replace(f'<{key.upper()}>', value)
     return text
