@@ -52,7 +52,7 @@ def mod_exec(config: PyConfig) -> None:
                      "code-aid/coverage.sh", "code-aid/pypi.sh",
                      'code-aid/build_sphinx.sh',
                      config.project.name + "/__main__.py"):
-        _mod_exec(config.project.joinpath(exe_path))
+        _mod_exec(config.project / exe_path)
 
 
 def tree_copy(config: PyConfig,
@@ -69,9 +69,9 @@ def tree_copy(config: PyConfig,
 
     - Nodes handling:
 
-      - Directories are created
-      - Links are interpreted and linked,
-      - Files are modified-edit and written
+      - create directories
+      - interpret links and link them
+      - :meth:`edit_modify` and write files
 
     Args:
         config: pyprojstencil configuration
@@ -101,27 +101,26 @@ def tree_copy(config: PyConfig,
 
     # Add missed files
     if stack == 0:
-        dest_root.joinpath("LICENSE").write_text(
+        (dest_root / "LICENSE").write_text(
             edit_modify(config.license.read_text(), config))
         for missing_dirs in ("docs/_build", "docs/_static", "docs/_templates",
                              "docs/docs"):
-            dest_root.joinpath(missing_dirs).mkdir(parents=True, exist_ok=True)
-        dest_root.joinpath("docs/docs/coverage.svg").symlink_to(
-            "../coverage.svg")
+            (dest_root / missing_dirs).mkdir(parents=True, exist_ok=True)
+        (dest_root / "docs/docs/coverage.svg").symlink_to("../coverage.svg")
 
     for node in src_root.glob("*"):
         if node.is_file():
             # file
             if node.name[-4:] == ".pyc":
                 continue
-            dest_root.joinpath(node.name.replace("dot.", ".")).write_text(
+            (dest_root / node.name.replace("dot.", ".")).write_text(
                 edit_modify(node.read_text(), config))
         elif node.is_symlink():
             # relative link
             # NEXT: in python3.9 os.readlink is replaced by Path().readlink
             symlink_target = Path(os.readlink(node)).relative_to(src_root)
-            dest_root.joinpath(node.name.replace("dot.", ".")).symlink_to(
-                dest_root.joinpath(symlink_target),
+            (dest_root / node.name.replace("dot.", ".")).symlink_to(
+                (dest_root / symlink_target),
                 target_is_directory=Path(os.readlink(node)).is_dir())
         elif node.name in (".git", ".venv", "__pycache__", "licenses"):
             # skip
@@ -129,9 +128,9 @@ def tree_copy(config: PyConfig,
         elif node.is_dir():
             # directory: recurse
             if node.name == "src":
-                dirname = dest_root.joinpath(config.project.name)
+                dirname = dest_root / config.project.name
             else:
-                dirname = dest_root.joinpath(node.name.replace("dot.", "."))
+                dirname = dest_root / node.name.replace("dot.", ".")
             ret_code &= tree_copy(config,
                                   node,
                                   dirname,
