@@ -45,7 +45,7 @@ def get_license(l_name: str = 'LGPLv3',
         LicenseNotKnownError: Provided license is not found
 
     """
-    for license_h in INFO_BASE.templates.joinpath("licenses").glob("*"):
+    for license_h in (INFO_BASE.templates / "licenses").glob("*"):
         if not license_h.is_file():
             continue
         if license_h.name == l_name:
@@ -53,18 +53,16 @@ def get_license(l_name: str = 'LGPLv3',
             header_h = license_h.with_stem(license_h.stem + "_header")
             if header_h.is_file():
                 return license_h, header_h.read_text()
-            return (license_h,
-                    INFO_BASE.templates.joinpath(
-                        "licenses/custom_header").read_text())
+            return (license_h, (INFO_BASE.templates /
+                                "licenses/custom_header").read_text())
         elif license_h.name == l_name + "_header":
             # found header file
             text_h = license_h.with_stem(license_h.stem.replace("_header", ""))
             if text_h.is_file():
                 return text_h, license_h.read_text()
-            return (INFO_BASE.templates.joinpath("licenses/custom"),
+            return (INFO_BASE.templates / "licenses/custom",
                     license_h.read_text())
     if return_blank:
-        return (
-            INFO_BASE.templates.joinpath("licenses/custom"),
-            INFO_BASE.templates.joinpath("licenses/custom_header").read_text())
+        return (INFO_BASE.templates / "licenses/custom",
+                (INFO_BASE.templates / "licenses/custom_header").read_text())
     raise LicenseNotKnownError(l_name)
