@@ -23,7 +23,7 @@ Initialize git repository
 
 import git
 
-from .configure import PyConfig
+from pyprojstencil.configure import PyConfig
 
 
 def init_git_repo(config: PyConfig):
