@@ -20,9 +20,13 @@
 
 # Always run this script from its immediate parent folder
 
+. "$(dirname "${0}")/common.sh" || exit 127
 
 set_vars () {
-    usage="usage: $0 [-h] [--help]"
+    usage="
+usage:
+    $0 [-h]
+    $0 [--help]"
     cwd="${PWD}"
     realenv=
     mk_flags=""
@@ -43,7 +47,6 @@ set_vars () {
 }
 
 unset_vars () {
-    cd "${cwd}" || exit 5
     unset usage
     unset help_msg
     unset cwd
@@ -51,29 +54,19 @@ unset_vars () {
     unset mk_flags
     unset project_root
     unset project_name
-}
-
-clean_exit () {
-    unset_vars
-    if [ -z "${1}" ]; then
-        exit 0
-    else
-        exit "${1}"
-    fi
+    cd "${cwd}" || exit 5
 }
 
 cli() {
     while test $# -gt 0; do
         case "${1}" in
             -h)
-                printf "%s\n" "${usage}"
-                clean_exit 0
+                clean_exit 0 "${usage}"
                 ;;
             --help)
                 printf "%s\n" "${usage}"
                 # shellcheck disable=SC2059
-                printf "${help_msg}\n"
-                clean_exit 0
+                clean_exit 0 "${help_msg}"
                 ;;
             -r|--realenv)
                 realenv=true
@@ -91,22 +84,6 @@ cli() {
     done
 }
 
-check_venv() {
-    if [ -z "${VIRTUAL_ENV}" ] && [ ! ${realenv} ]; then
-        printf "\033[1;31m[ERROR]\033[m Not working in a virtualenv\n\n" >&2
-        printf "    \033[32m[Recommended]\033[m " >&2
-        echo "activate virtualenv by typing without '# ':" >&2
-        printf "        # \033[97msource " >&2
-        printf "%s/.venv/bin/activate\033[m\n\n" "${project_root}">&2
-        printf "    \033[31m[Risky]\033[m " >&2
-        printf "else, use --realenv flag to override this error\n" >&2
-        printf "        \033[33mDo this only if " >&2
-        printf "you understand virtualenv\033[m\n\n" >&2
-        echo "Aborting..."
-        exit 1
-    fi
-}
-
 make_docs () {
     pip install -U -r requirements.txt
     sphinx-build -b html "${project_root}/docs" \
