@@ -21,14 +21,21 @@
 # Always run this script from its immediate parent folder
 
 
+. "$(dirname "${0}")/common.sh" || exit 127
+
+
 set_vars () {
-    usage="usage: $0 [-h] [--help] [-y|--assume-yes] [-r|--realenv] [*]"
+    usage="
+usage:
+    $0 -h
+    $0 --help
+    $0 [-y|--assume-yes] [-r|--realenv] [*] "
     cwd="${PWD}"
     realenv=
     ct_flags=""
     project_root="$(dirname "$(dirname "$(readlink -f "${0}")")")"
     project_name="$(basename "${project_root}")"
-    help_msg="
+    help_msg="${usage}
 
     DESCRIPTION: Run unit tests in ${project_root}/tests folder
     and create a ${project_root}/docs/coverage.svg badge
@@ -44,7 +51,6 @@ set_vars () {
 }
 
 unset_vars () {
-    cd "${cwd}" || exit 5
     unset usage
     unset help_msg
     unset cwd
@@ -52,29 +58,17 @@ unset_vars () {
     unset ct_flags
     unset project_root
     unset project_name
-}
-
-clean_exit () {
-    unset_vars
-    if [ -z "${1}" ]; then
-        exit 0
-    else
-        exit "${1}"
-    fi
+    cd "${cwd}" || exit 65
 }
 
 cli() {
     while test $# -gt 0; do
         case "${1}" in
             -h)
-                printf "%s\n" "${usage}"
-                clean_exit 0
+                clean_exit 0 "${usage}"
                 ;;
             --help)
-                printf "%s\n" "${usage}"
-                # shellcheck disable=SC2059
-                printf "${help_msg}\n"
-                clean_exit 0
+                clean_exit 0 "${help_msg}"
                 ;;
             -r|--realenv)
                 realenv=true
@@ -92,22 +86,6 @@ cli() {
     done
 }
 
-check_venv() {
-    if [ -z "${VIRTUAL_ENV}" ] && [ ! ${realenv} ]; then
-        printf "\033[1;31m[ERROR]\033[m Not working in a virtualenv\n\n" >&2
-        printf "    \033[32m[Recommended]\033[m " >&2
-        echo "activate virtualenv by typing without '# ':" >&2
-        printf "        # \033[97msource " >&2
-        printf "%s/.venv/bin/activate\033[m\n\n" "${project_root}">&2
-        printf "    \033[31m[Risky]\033[m " >&2
-        printf "else, use --realenv flag to override this error\n" >&2
-        printf "        \033[33mDo this only if " >&2
-        printf "you understand virtualenv\033[m\n\n" >&2
-        echo "Aborting..."
-        exit 1
-    fi
-}
-
 coverage_test () {
     coverage run -m pytest --junitxml=report.xml "${project_root}/tests"
     coverage xml
@@ -118,7 +96,7 @@ main () {
     set_vars "$*"
     cli "$*"
     check_venv
-    cd "${project_root}/tests" || exit 5
+    cd "${project_root}/tests" || clean_exit 65
     coverage_test
     clean_exit
 }
