@@ -21,15 +21,22 @@
 # Always run this script from its immediate parent folder
 
 
+. "$(dirname "${0}")/common.sh" || exit 127
+
+
 set_vars () {
-    usage="usage: $0 [-h] [--help] [-y|--assume-yes] [-r|--realenv] [*]"
+    usage="
+usage:
+    $0 -h
+    $0 --help
+    $0 [-y|--assume-yes] [-r|--realenv] [*]"
     cwd="${PWD}"
     realenv=
     assume_yes=""
     in_flags=""
     project_dir="$(dirname "$(dirname "$(readlink -f "${0}")")")"
     project_name="$(basename "${project_dir}")"
-    help_msg="
+    help_msg="${usage}
 
     DESCRIPTION: install \033[3m${project_name}/requirements.txt\033[m
        on ${VIRTUAL_ENV:-user\'s environment}
@@ -56,27 +63,14 @@ unset_vars () {
     unset project_name
 }
 
-clean_exit () {
-    unset_vars
-    if [ -z "${1}" ]; then
-        exit 0
-    else
-        exit "${1}"
-    fi
-}
-
 cli() {
     while test $# -gt 0; do
         case "${1}" in
             -h)
-                printf "%s\n" "${usage}"
-                clean_exit 0
+                clean_exit 0 "${usage}"
                 ;;
             --help)
-                printf "%s\n" "${usage}"
-                # shellcheck disable=SC2059
-                printf "${help_msg}\n"
-                clean_exit 0
+                clean_exit 0 "${help_msg}"
                 ;;
             -r|--realenv)
                 realenv=true
@@ -90,22 +84,6 @@ cli() {
     done
 }
 
-check_venv() {
-    if [ -z "${VIRTUAL_ENV}" ] && [ ! ${realenv} ]; then
-        printf "\033[1;31m[ERROR]\033[m Not working in a virtualenv\n\n" >&2
-        printf "    \033[32m[Recommended]\033[m " >&2
-        echo "activate virtualenv by typing without '# ':" >&2
-        printf "        # \033[97msource " >&2
-        printf "%s/.venv/bin/activate\033[m\n\n" "${project_dir}">&2
-        printf "    \033[31m[Risky]\033[m " >&2
-        printf "else, use --realenv flag to override this error\n" >&2
-        printf "        \033[33mDo this only if " >&2
-        printf "you understand virtualenv\033[m\n\n" >&2
-        echo "Aborting..."
-        exit 1
-    fi
-}
-
 pip_install () {
     # DONT: we do WANT to glob this
     # shellckeck disable=SC2086
@@ -117,7 +95,7 @@ pip_install () {
 main () {
     set_vars "$*"
     cli "$*"
-    cd "${project_dir}/code-aid" || exit 5
+    cd "${project_dir}/code-aid" || clean_exit 65
     check_venv
     pip_install
     clean_exit
