@@ -21,15 +21,21 @@
 # Always run this script from its immediate parent folder
 
 
+. "$(dirname "${0}")/common.sh" || exit 127
+
+
 set_vars () {
-    usage="usage: $0 [-h] [--help] [-y|--assume-yes] [-r|--realenv] [*]"
+    usage="
+usage: $0 -h
+    $0 --help
+    $0 [-y|--assume-yes] [-r|--realenv] [*]"
     cwd="${PWD}"
     realenv=
     assume_yes=""
     in_flags=""
     project_root="$(dirname "$(dirname "$(readlink -f "${0}")")")"
     project_name="$(basename "${project_root}")"
-    help_msg="
+    help_msg="${usage}
 
     DESCRIPTION: [Uninstall \033[3m${project_name}\033[m if it exists and re-]
     install \033[3m${project_name}\033[m
@@ -59,27 +65,14 @@ unset_vars () {
     unset project_name
 }
 
-clean_exit () {
-    unset_vars
-    if [ -z "${1}" ]; then
-        exit 0
-    else
-        exit "${1}"
-    fi
-}
-
 cli() {
     while test $# -gt 0; do
         case "${1}" in
             -h)
-                printf "%s\n" "${usage}"
-                clean_exit 0
+                clean_exit 0 "${usage}"
                 ;;
             --help)
-                printf "%s\n" "${usage}"
-                # shellcheck disable=SC2059
-                printf "${help_msg}\n"
-                clean_exit 0
+                clean_exit 0 "${help_msg}"
                 ;;
             -r|--realenv)
                 realenv=true
@@ -97,22 +90,6 @@ cli() {
     done
 }
 
-check_venv() {
-    if [ -z "${VIRTUAL_ENV}" ] && [ ! ${realenv} ]; then
-        printf "\033[1;31m[ERROR]\033[m Not working in a virtualenv\n\n" >&2
-        printf "    \033[32m[Recommended]\033[m " >&2
-        echo "activate virtualenv by typing without '# ':" >&2
-        printf "        # \033[97msource " >&2
-        printf "%s/.venv/bin/activate\033[m\n\n" "${project_root}">&2
-        printf "    \033[31m[Risky]\033[m " >&2
-        printf "else, use --realenv flag to override this error\n" >&2
-        printf "        \033[33mDo this only if " >&2
-        printf "you understand virtualenv\033[m\n\n" >&2
-        echo "Aborting..."
-        exit 1
-    fi
-}
-
 pip_uninstall() {
     if command -v "${project_name}" >/dev/null 2>&1; then
         pip uninstall ${assume_yes} "${project_name}" || clean_exit "$?"
@@ -122,14 +99,14 @@ pip_uninstall() {
 pip_install () {
     # DONT: we do WANT to glob this
     # shellckeck disable=SC2086
-    pip install ${in_flags} ".."
+    pip install ${in_flags} --editable ".."
 }
 
 main () {
     set_vars "$*"
     cli "$*"
     check_venv
-    cd "${project_root}/code-aid" || exit 5
+    cd "${project_root}/code-aid" || clean_exit 65
     pip_uninstall
     pip_install
     clean_exit
