@@ -22,15 +22,23 @@
 
 # NOTE: You MUST alter some parts of this script, eg: pypi's username, password
 
+
+. "$(dirname "${0}")/common.sh" || exit 127
+
+
 set_vars () {
-    usage="usage: $0 [-h] [--help] [-r|--release] [*]"
+    usage="
+usage:
+    $0 -h
+    $0 --help
+    $0 [-r|--release] [*]"
     cwd="${PWD}"
     realenv=
     up_flags=
     release="testpypi"
     project_dir="$(dirname "$(dirname "$(readlink -f "${0}")")")"
     project_name="$(basename "${project_dir}")"
-    help_msg="
+    help_msg="${usage}
 
     DESCRIPTION: Distribute package to [test]pypi
 
@@ -55,27 +63,14 @@ unset_vars () {
     unset project_name
 }
 
-clean_exit () {
-    unset_vars
-    if [ -z "${1}" ]; then
-        exit 0
-    else
-        exit "${1}"
-    fi
-}
-
 cli() {
     while test $# -gt 0; do
         case "${1}" in
             -h)
-                printf "%s\n" "${usage}"
-                clean_exit 0
+                clean_exit 0 "${usage}"
                 ;;
             --help)
-                printf "%s\n" "${usage}"
-                # shellcheck disable=SC2059
-                printf "${help_msg}\n"
-                clean_exit 0
+                clean_exit 0 "${help_msg}"
                 ;;
             -r|--release)
                 release="pypi"
@@ -89,22 +84,6 @@ cli() {
     done
 }
 
-check_venv() {
-    if [ -z "${VIRTUAL_ENV}" ] && [ ! ${realenv} ]; then
-        printf "\033[1;31m[ERROR]\033[m Not working in a virtualenv\n\n" >&2
-        printf "    \033[32m[Recommended]\033[m " >&2
-        echo "activate virtualenv by typing without '# ':" >&2
-        printf "        # \033[97msource " >&2
-        printf "%s/.venv/bin/activate\033[m\n\n" "${project_dir}">&2
-        printf "    \033[31m[Risky]\033[m " >&2
-        printf "else, use --realenv flag to override this error\n" >&2
-        printf "        \033[33mDo this only if " >&2
-        printf "you understand virtualenv\033[m\n\n" >&2
-        echo "Aborting..."
-        exit 1
-    fi
-}
-
 pip_twine () {
     # start from scratch
     rm -rf "${project_dir}/build" "${project_dir}/dist"
@@ -132,7 +111,7 @@ main () {
     set_vars "$*"
     cli "$*"
     check_venv
-    cd "${project_dir}/code-aid" || exit 5
+    cd "${project_dir}/code-aid" || clean_exit 65
     pip_twine
     clean_exit
 }
