@@ -19,12 +19,14 @@ sys.path.insert(0, os.path.abspath('..'))
 
 # -- Project information -----------------------------------------------------
 
-project = '<PROJECT>'
-copyright = '<YEARS>, <AUTHOR>'
-author = '<AUTHOR>'
+from <PROJECT> import __author__, __copyright_years__, __name__, __version__
+
+project = __name__
+copyright = f'Copyright © {__copyright_years__}, {__author__}'
+author = __author__
 
 # The full version, including alpha/beta/rc tags
-release = '<VERSION>'
+release = __version__
 
 # -- General configuration ---------------------------------------------------
 
