@@ -1,9 +1,7 @@
 #!/usr/bin/env python<PYVERSION>
 # -*- coding: utf-8; mode: python; -*-
 <LICENSE_HEADER>
-"""
-Command-line Callable
-"""
+"""Command-line Callable"""
 
 def main():
     return 0
