@@ -1,14 +1,10 @@
 #!/usr/bin/env python<PYVERSION>
 # -*- coding: utf-8; mode: python; -*-
 <LICENSE_HEADER>
-"""
-<PROJECT>'s defined errors
-"""
+"""<PROJECT>'s defined errors"""
 
 
 class <PROJECT>Error(Exception):
-    """
-    Base error for <PROJECT>(Exception):
-    """
+    """Base error for <PROJECT>(Exception)"""
     def __init__(self, *args):
-        super(Exception, self).__init__(*args)
+        super().__init__(*args)
