@@ -1,6 +1,4 @@
 #!/usr/bin/env python<PYVERSION>
 # -*- coding: utf-8; mode: python; -*-
 <LICENSE_HEADER>
-"""
-unit tests
-"""
+"""unit tests"""
