@@ -28,4 +28,4 @@ from pyprojstencil.configure import read_config
 
 class TestConfig(TestCase):
     def test_default_config(self):
-        default_config = read_config()
+        default_config = read_config('test_project')
